summaryrefslogtreecommitdiff
path: root/gtk2_ardour/time_axis_view.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2005-10-06 19:10:57 +0000
committerPaul Davis <paul@linuxaudiosystems.com>2005-10-06 19:10:57 +0000
commit4c509656223d3ed1f0fab504cb483090d38972f9 (patch)
tree540f207b81f957fa78101d67da3094ff1e1f9456 /gtk2_ardour/time_axis_view.cc
parent5a52d8fee4c9abac7ffb1f1e6464785d979acd68 (diff)
fix compose mess, and a number of 64 bit printf specs
git-svn-id: svn://localhost/trunk/ardour2@51 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/time_axis_view.cc')
-rw-r--r--gtk2_ardour/time_axis_view.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk2_ardour/time_axis_view.cc b/gtk2_ardour/time_axis_view.cc
index bee45147af..9e4c427233 100644
--- a/gtk2_ardour/time_axis_view.cc
+++ b/gtk2_ardour/time_axis_view.cc
@@ -47,7 +47,7 @@
#include "i18n.h"
using namespace Gtk;
/*can't use sigc namespace while we have the compose() in libs/pbd3/pbd */
//using namespace sigc;
using namespace ARDOUR;
using namespace Editing;
@@ -783,7 +783,7 @@ TimeAxisView::set_state (const XMLNode& node)
} else if (prop->value() == "small") {
set_height (Small);
} else {
- error << compose(_("unknown track height name \"%1\" in XML GUI information"), prop->value()) << endmsg;
+ error << string_compose(_("unknown track height name \"%1\" in XML GUI information"), prop->value()) << endmsg;
set_height (Normal);
}
@@ -47,7 +47,7 @@
#include "i18n.h"
using namespace Gtk;
-/*can't use sigc namespace while we have the compose() in libs/pbd3/pbd */
+/*can't use sigc namespace while we have the string_compose() in libs/pbd3/pbd */
//using namespace sigc;
using namespace ARDOUR;